Crate assemblyline_filestore
assemblyline_
filestore
0.2.1
All Items
Crate Items
Modules
Structs
Crate
assemblyline_
filestore
A library that provides adaptors to blob storage for the assemblyline platform.
Modules

errors
Errors potentially used by multiple transports
Structs

File
Store
An abstract interface over one or more storage transports.